#!/bin/bash
#GPL, mimooh at pld-linux.org
#This script guesses the configuration of harddisks and sets up GRUB

detect_hd_number() {
	echo $1 | grep 'a' && hd_number=1 || hd_number=2 # hda/sda are first disk, other are 2 disk
	[ "X$1" = "X-" ] && hd_number='-'
	eval $2=$hd_number;
	show_verbose_message "detect_hd_number: $1 -> $2=$hd_number";
}

grub_numbers() { 	# win_part=/dev/hda12; grub_numbers $win_part -> grub_win_part=11
			# this func generates grub_kernel_part, grub_kernel_hd_number & friends
	grub_number=`basename \`echo $1\` | sed 's/[^[:digit:]]//g'`
	let grub_number-- 2>/dev/null || grub_number="" 
	eval $2=$grub_number
	show_verbose_message "grub_numbers: $1 -> $2=$grub_number"
}

detect_windows() {
	[ -n "$WIN32_CORE_DISK" ] || {  # loaded from /etc/pldconf/ustawienia
	  show_message "$(nls "Auto generating entries for windows partition in /etc/fstab, ok?")"
		pldconf -f -a
		. /etc/pldconf/ustawienia
	}
	win_part=$WIN32_CORE_DISK
	show_verbose_message "win_part guessed: $win_part"; 
	detect_hd_number $win_part win_hd_number
}

detect_linux() {
	root_part=`mount | head -1 | cut -f1 -d' '` || root_part='-'
	show_verbose_message "root_part guessed: $root_part"
	kernel_part=`mount | grep /boot | cut -f1 -d' '`
	[ -n "$kernel_part" ] || { kernel_part=$root_part; boot_prefix=/boot; }
	show_verbose_message "kernel_part guessed: $kernel_part"
	detect_hd_number $kernel_part kernel_hd_number
}

prepare_grub_variables() {
	[ "X$default_win" = "Xyes" ] && default_os=1 || default_os=0
	[ -n "$pass" ] && password="password $pass"
	grub_numbers $kernel_part grub_kernel_part
	grub_numbers $win_part grub_win_part
	grub_numbers $kernel_hd_number grub_kernel_hd_number
	grub_numbers $win_hd_number grub_win_hd_number
}

create_grub_entries() {
	cat > /boot/grub/menu.lst << EOF
default $default_os
timeout $timeout
color $color
$password

title $label_linux
root (hd$grub_kernel_hd_number,$grub_kernel_part)
kernel $boot_prefix/$kernel root=$root_part vga=$vga_mode
initrd $boot_prefix/$initrd

#$(nls "Active the 4 lines below if you have more linux systems")
#title $(nls "Your second linux")
#root (hd0,6) 
#kernel /boot/vmlinuz root=/dev/hda7
#initrd /boot/initrd

EOF

	[ -n "$grub_win_part" ] && cat >> /boot/grub/menu.lst << EOF
title $label_win
rootnoverify (hd$grub_win_hd_number,$grub_win_part)
chainloader +1

EOF

	#Failsafe entry for framebuffer
	[ "X$vga_mode" != "Xnormal" ] && cat >> /boot/grub/menu.lst << EOF
title PLD Linux failsafe
root (hd$grub_kernel_hd_number,$grub_kernel_part)
kernel $boot_prefix/$kernel root=$root_part
initrd $boot_prefix/$initrd
EOF
}

run_grub() {
	show_message "$(nls "You can ignore errors about floppy (fd0) and")
\"Can't locate module XXX\""

	/sbin/grub --batch << EOF
root (hd$grub_kernel_hd_number,$grub_kernel_part)
setup (hd0)
quit
EOF
}

grub_floppy() {
	cp /boot/grub/menu.lst /boot/grub/menu.lst.floppy
	cat >> /boot/grub/menu.lst.floppy << EOF
title $(nls "Install in") Master Boot Record
root (hd$grub_kernel_hd_number,$grub_kernel_part)
setup (hd0)
EOF

	umount /dev/fd0 2>/dev/null
	mkfs /dev/fd0 && { 
		mount -t ext2 /dev/fd0 /media/floppy;
	       	mkdir -p /media/floppy/boot/grub/;
		cp /boot/grub/stage1 /boot/grub/stage2 /media/floppy/boot/grub/;
		cp /boot/grub/menu.lst.floppy /media/floppy/boot/grub/menu.lst
		umount /dev/fd0
		/sbin/grub --batch <<- EOF
		root (fd0)
		setup (fd0)
		quit
		EOF
	} || show_message "$(nls "There are some problems with floppy, GRUB only on hard disk")";
}


run_main() {
	backup_file /boot/grub/menu.lst
	clear
	show_message "
$(nls "This module installs boot manager on hard disk and creates boot floppy, which is good and which you want. Thanks the floppy, you will be able to boot your PLD Linux when system is unbootable, e.g. after Windows installation (but not only then).")

$(nls "Insert floppy disk to floppy drive. It will be formated and GRUB boot manager will be installed on
it")

$(nls "Ignore errors which will appear if you don't want floppy disk, - GRUB will be installed only on hard disk")

"
	prepare_grub_variables
	[ "X$only_floppy" = "Xyes" ] || {
		create_grub_entries;
		run_grub;
	}
	[ "X$grub_floppy_skip" = "Xyes" ] || grub_floppy
	show_verbose_message "" "cat /boot/grub/menu.lst"
}

gui() {
	eval `dml << EOF
	<meta title="$(nls "GRUB - boot manager")"><br>
	$(nls "Default boot system (You can change the label)"):<br>
	<check id=default_linux checked=1> <input id=label_linux caption="PLD Linux" width=13><br>
	<check id=default_win> <input id=label_win caption="MS Windows" width=13><br><br>
	$(nls "Boot menu timeout"): <input id=timeout caption=5 width=4> $(nls "seconds"). 
	$(nls "Menu colors"): <input id=color caption="green/black" width=15><br>
	-----------------------------------------------------------------<br><br>
	$(nls "Windows on partition"): <input id=win_part caption=$win_part width=13>, $(nls "disk"): <input id=win_hd_number caption=$win_hd_number width=3><br>
	$(nls "Linux on partition"):   <input id=root_part caption=$root_part width=13> <br><br>
	Kernel: <input id=kernel caption=vmlinuz width=13>, initrd: <input id=initrd caption=initrd width=13><br>
	$(nls "in /boot on"): <input id=kernel_part caption=$kernel_part width=13>, 
	$(nls "disk"): <input id=kernel_hd_number caption=$kernel_hd_number width=3><br><br>
	$(nls "Framebuffer mode"): <input id=vga_mode width=13 caption=normal> <button id=dml_vga_help caption="$(nls "Modes...")"><br>
	$(nls "Lock GRUB command line"): <input id=pass width=13><br><br>
	\`dml_buttons Ok Anuluj Edytuj Przywr Pomoc\`
EOF`

	[ "X$dml_vga_help" = "Xyes" ] && { show_message "

Framebuffer - $(nls "graphic modes")
------------------------------

    | 640x480  800x600  1024x768 1280x1024
----+-------------------------------------
256 |  0x301    0x303    0x305    0x307   
32k |  0x310    0x313    0x316    0x319   
64k |  0x311    0x314    0x317    0x31A   
16M |  0x312    0x315    0x318    0x31B   
"
	exec $0; }

	dml_cancel_check ${DATA_DIR}/BOOT/boot_menu.sh
	dml_edit_check /boot/grub/menu.lst
	dml_recover_check ${CONF_DIR}/menu.lst /boot/grub/menu.lst
	dml_help_check ${DATA_DIR}/POMOC/README_boot_manager.txt
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
}

label_linux="PLD Linux"
label_win="MS Windows"
kernel=vmlinuz
initrd=initrd
default_linux=yes
default_win=no
timeout=5
vga_mode=normal
color="green/black"

print_help() {
	cat << EOF
GRUB, $(nls "options"):
-a		$(nls "auto configuration");
-w		$(nls "skip windows partition configuration");
-W		$(nls "default windows instead of linux");
-t $(nls "<time>  menu appearance time (default 5 seconds)");
-f		$(nls "don't create floppy disk");
-F              $(nls "create only floppy disk");
-c <fg/bg>	$(nls "foreground/background (default green/black)");
-p <password>   $(nls "password for GRUB command line mode");
-h -?		$(nls "help");

EOF
}

while getopts "awWt:fFc:p:h" opt
do
	case $opt in
		a) echo "$(nls "auto configuration")";;
		w) WIN32_CORE_DISK='-';; 
		W) default_win="yes";;
		t) timeout="$OPTARG";;
		f) grub_floppy_skip="yes";;
		F) only_floppy="yes";;
		c) color="$OPTARG";;
		p) pass="$OPTARG";;
		h) print_help; exit;;
		*) print_help; exit;;
	esac
done

install_if_missing grub
detect_windows
detect_linux
[ -z "$1" ] && gui || run_main 2>/dev/null
