#!/bin/bash
# GPL,teodor at pld-linux.org
#

runlevel=`runlevel | cut -b3`
services="`chkconfig --list | cut -f1`"
unset service_menu

services_list () {
	unset service_menu sort_mode
	case $1 in
		all) {
			for i in $services; do
				service_menu="$service_menu <item id=$i> $i"
			done
			sort_mode="$(nls "All")"
		};;
		disabled) {
			for i in $services; do
				[ "`ls /etc/rc.d/rc$runlevel.d|grep $i`" ] || service_menu="$service_menu <item id=$i> $i";
			done
			sort_mode="$(nls "Disabled")"
		};;
		enabled) {
			for i in $services; do
				[ "`ls /etc/rc.d/rc$runlevel.d|grep $i`" ] && service_menu="$service_menu <item id=$i> $i";
			done
			sort_mode="$(nls "Enabled")"
		};;
	esac					
}

info_gui () {
	eval `dml << EOF
	<meta title="$(nls "Information about service")"><br>
	$(nls "Services"): $ser_menu<br>
	$(nls "Description"):<br><br>
	<text height=4>
	$description
	</text><br>
	$(nls "Start on runlevels"): $runlevels<br><br>
	<button id=service_start caption="$(nls "Start")"> <button id=service_stop caption="$(nls "Stop")"> <button id=service_restart caption="$(nls "Restart")"> 
	<button id=service_disable caption="$(nls "Disable")"> <button id=service_enable caption="$(nls "Enable")"><br><br>
	<button id=back caption="$(nls "Back")">
EOF`

}

info () {
	unset runlevels description
	name=$ser_menu
	[ "$ser_menu" = "syslog-ng" ] && { name=syslog; }
	description=`cat /etc/rc.d/init.d/$ser_menu|sed -ne "/^# $name/,/./p;"|sed -e "s/# nfs//g; s/#//g;"|tr '\n' ' '|sed -e "s/\\t//g; s/^ $name//g;"`
	runlevels="`chkconfig --list | grep -w $ser_menu | sed -e 's/:\*\*\*/ yes /g; s/:---/ no /g;' | cut -f2-`"
	info_gui
	[ "X$service_start" = "Xyes" ] && /etc/rc.d/init.d/$ser_menu start;
	[ "X$service_stop" = "Xyes" ] && /etc/rc.d/init.d/$ser_menu stop;
	[ "X$service_disable" = "Xyes" ] && { chkconfig --del $ser_menu; show_verbose_message "$(nls "Service was disabled")" "chkconfig --list | egrep -C 5 --color '$ser_menu'"; };
	[ "X$service_enable" = "Xyes" ] && { chkconfig --add $ser_menu; show_verbose_message "$(nls "Service was enabled")" "chkconfig --list | egrep -C 5 --color '$ser_menu'"; };
	[ "X$service_restart" = "Xyes" ] && /etc/rc.d/init.d/$ser_menu restart;
}

run_main () {
	[ $runlevel -ne $level ] && {
		line_replace "id:" "id:$level:initdefault:" /etc/inittab;
		yes_no "$(nls "Do you want to change runlevel immediately?")" "/sbin/init $level";
	}
}

gui () {
	eval `dml<< EOF
	<meta title="$(nls "Services")" height=25><br>
	<menu id=levels hidden=1>
	<item id=1> single (1)
	<item id=2> normal (2) $(nls "without network")
	<item id=3> normal (3)
	<item id=5> X11    (5)
	</menu>
	$(nls "Show services (sort mode)"):<br>
	<button id=enabled caption="$(nls "Enabled")"> <button id=disabled caption="$(nls "Disabled")"> <button id=all_services caption="$(nls "All")"><br><br>
	$sort_mode $(nls "services"):<br>
	<menu id=ser_menu height=13>
	$service_menu
	</menu><br>
	$(nls "Select service and") <button id=information caption="$(nls "Show information")"><br>
	$(nls "Current runlevel is:") <input id=level caption=$runlevel width=3 menu=levels label="$(nls "Change")"><br>
	\`dml_buttons Ok Anuluj Pomoc\`
EOF`
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
	dml_cancel_check ${DATA_DIR}/BOOT/boot_menu.sh
	dml_help_check ${DATA_DIR}/POMOC/README_services.txt
	[ "X$enabled" = "Xyes" ] && { services_list enabled; gui; }
	[ "X$disabled" = "Xyes" ] && { services_list disabled; gui; }
	[ "X$all_services" = "Xyes" ] && { services_list all; gui; } 
	[ "X$information" = "Xyes" ] && { info; gui; }
}
services_list all
gui
