#!/bin/bash
#
# mouse.sh				This basic module help you to configure your mouse
#									to work on console as well as in X environment
# Author:					Jakub Krajniak <teodor at pld-linux.org>
# Changes:				Karol Kreski <mimooh at pld-linux.org>
#
# $Id:$
#

GPM_CONF_FILE="/etc/sysconfig/mouse"
X_CONF_FILE="/etc/X11/xorg.conf"

run_main () {	
	case $mouse_type in
		1) X_MOUSE_PROTOCOL="IMPS/2"; GPM_MOUSE_PROTOCOL="imps2" ;;
		2) X_MOUSE_PROTOCOL="PS/2"; GPM_MOUSE_PROTOCOL="PS/2" ;;
		3) X_MOUSE_PROTOCOL="Microsoft"; GPM_MOUSE_PROTOCOL="ms3" ;;
		4) X_MOUSE_PROTOCOL="Microsoft"; GPM_MOUSE_PROTOCOL="ms" ;;
		5) X_MOUSE_PROTOCOL="Logitech"; GPM_MOUSE_PROTOCOL="bm" ;;
	esac

	case $mouse_port in
		1) mouse_port="/dev/psaux"; modules="psmouse" ;;
		2) mouse_port="/dev/ttyS0";;
		3) mouse_port="/dev/ttyS1";;
		4) mouse_port="/dev/input/mouse0"; modules="hid usbmouse" ;;
	esac
	ln -sf $mouse_port /dev/mouse

	for m in $modules; do  
		# make sure modules can be loaded before they go into /etc/modules
		grep $m /etc/modules && line_replace "$m" "$m" /etc/modules
		modprobe $m 2>/dev/null && line_replace "$m" "$m" /etc/modules
	done

	if [ -f $X_CONF_FILE ]; then
		line_replace "export X_MOUSE_PROTOCOL" "export X_MOUSE_PROTOCOL=\"$X_MOUSE_PROTOCOL\"" ${CONF_DIR}/ustawienia 
		line_replace ".*Option \"Protocol\"" "\\tOption \"Protocol\" \"$X_MOUSE_PROTOCOL\"" $X_CONF_FILE 
	fi
	export X_MOUSE_PROTOCOL

	if [ "X$gpm_mouse" = "Xyes" ]; then
		install_if_missing gpm
		backup_file ${GPM_CONF_FILE}
		line_replace "DEVICE" "DEVICE=/dev/mouse" ${GPM_CONF_FILE} 
		line_replace "MOUSETYPE" "MOUSETYPE=$GPM_MOUSE_PROTOCOL" ${GPM_CONF_FILE} 
		[ $lefthand_user = no ] && line_replace "BUTTON_SEQ" "BUTTON_SEQ=123" ${GPM_CONF_FILE}
		[ $lefthand_user = yes ] && line_replace "BUTTON_SEQ" "BUTTON_SEQ=321" ${GPM_CONF_FILE}
		/etc/rc.d/init.d/gpm restart
	fi
}

gui () {
	eval `dml << EOF
	<meta title="$(nls "Mouse setup")"> 
	<br>
	$(nls "Mouse type/protocol"): <br>
	<menu id=mouse_type width=34>
	<item id=1> $(nls "mouse with rolls (IMPS/2)")
	<item id=2> PS/2
	<item id=3> Microsoft (ms3)
	<item id=4> Microsoft (ms)
	<item id=5> Logitech
	</menu><br>
	Port: <br>
	<menu id=mouse_port width=34>
	<item id=1> PS/2       (/dev/psaux)
	<item id=2> $(nls "serial")  (/dev/ttyS0, COM1)
	<item id=3> $(nls "serial")  (/dev/ttyS1, COM2)
	<item id=4> USB        (/dev/input/mouse0)
	</menu><br><br>
	<check id=gpm_mouse> $(nls "Configure mouse for console also (gpm)") <br>
	<check id=lefthand_user> $(nls "Mouse for left-handed") <br><br>
	\`dml_buttons Ok Anuluj Edytuj Pomoc\`
EOF`
	dml_cancel_check ${DATA_DIR}/DEVICES/device_menu.sh
	dml_edit_check /etc/sysconfig/mouse
	dml_help_check ${DATA_DIR}/POMOC/README_mouse.txt
	dml_check_the_rest $where_to_return
}

print_help () {
	cat << EOF
pldconf mouse configurator

 -m <$(nls "mouse type")>:
    1	$(nls "mouse with rolls")
    2	$(nls "PS/2 without rolls")
    3	Microsoft ms3
    4	Microsoft ms
    5	Logitech

 -p <$(nls "port")>:
    1	/dev/psaux; PS/2
    2	/dev/ttyS0; COM1; $(nls "serial")
    3	/dev/ttyS1; COM2; $(nls "serial")
    4	/dev/input/mouse0; USB
    
 -g $(nls "configuration for gpm (console)")
 -G $(nls "GUI (default)")
 -h $(nls "help")

EOF
}

where_to_return="${DATA_DIR}/DEVICES/device_menu.sh"
while getopts "m:p:gxGh" opt
do
	case $opt in
		m) mouse_type="$OPTARG";;
		p) mouse_port="$OPTARG";;
		g) gpm_mouse="yes";;
		x) where_to_return="${DATA_DIR}/X/X.sh";; # when called from X.sh
		G) gui;;
		h) print_help; exit;;
		*) print_help; exit;;
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
