#!/bin/bash
#
# dhcpd.sh			This module try to guess structure of LAN, and
#               create config file for DHCP server
# 
# Author: Jakub Krajniak <teodor at pld-linux.org>, mimooh at pld-linux.org
# License: GPL
#
# $Id:$
#

detect_configuration () {
	eval `dml<< EOF
	<meta title="$(nls "dhcp interface")"><br><br>
	$(nls "interface"): <input id=interface caption=eth0 width=6><br>
	\`dml_buttons Ok Anuluj\`
EOF`
	ip_and_mask=`ip addr show dev $interface | grep "inet " | head -n 1 | cut -f 6 -d " "`
	ip_address=`echo $ip_and_mask | cut -f 1 -d "/"`
	prefix=`echo $ip_and_mask | cut -f 2 -d "/"`
	eval `ipcalc -m $ip_address` 		# NETMASK=x.x.x.x
	eval `ipcalc -n $ip_address/$prefix` 	# NETWORK=y.y.y.y
	eval `ipcalc -b $ip_address/$prefix`	# BROADCAST=z.z.z.z
	domain=`hostname -d`
	dns_address="`cat /etc/resolv.conf | egrep "^nameserver" | cut -f2 -d' ' | head -n 1`"

	eval `dml<< EOF
	<meta title="$(nls "DHCP service configuration")"><br><br>
	<button id=clear_config caption="$(nls "Clear config")"><br><br>
	$(nls "Network parametrs"): <br>
	$(nls "IP address"): <input id=ip_address caption=$ip_address><br>
	$(nls "Netmask"): <input id=netmask caption=$NETMASK><br>
	$(nls "Network address"): <input id=net_address caption=$NETWORK><br>
	$(nls "broadcast_address"): <input id=broadcast_address caption=$BROADCAST><br>
	$(nls "Domain"): <input id=domain caption=$domain><br><br>
	\`dml_buttons Ok Edytuj Anuluj\`
EOF`
	[ "X$clear_config" = "Xyes" ] && { echo > /etc/dhcpd.conf; exec $0; }
	dml_edit_check /etc/dhcpd.conf
}

detect_mac_address () {
	install_if_missing nmap
	for m in `arp -na | cut -f2 -d' ' | sed -e 's/)//g; s/(//g'`; do
		arp -d "$m" # clear arp cache
	done 

	echo "nmap -sP -v \"$net_address/$prefix\" 2>/dev/null"
	echo "$(nls "Scanning network, please wait")"
	nmap -sP -v "$net_address/$prefix" 2>/dev/null
	arp -na | grep -v incomplete | while read line; do
		ip="`echo $line | cut -f2 -d' ' | sed -e 's/)//g; s/(//g'`"
		mac="`echo $line | cut -f4 -d' '`"
		echo "$ip $mac" >> $MAC_FILE
	done
	sort $MAC_FILE | uniq | grep -v "00:00:00:00:00:00" > $MAC_FILE.tmp
	mv $MAC_FILE.tmp $MAC_FILE
	$EDITOR $MAC_FILE
}

add_mac_address () {
	sed -ie "/^#.*/d;" $MAC_FILE
	drop_section "host ranger" "}" ${CONF_FILE}
	while read line; do
		let u++
		ip="`echo $line | cut -f1 -d' '`"
		mac="`echo $line | cut -f2 -d' '`"
		echo "$ip :: $mac"
		cat >> ${CONF_FILE} << EOF 
host user$u {
	hardware ethernet $mac;
	fixed-address $ip;
}

EOF
	done < ${MAC_FILE} 
	arp -f /etc/ethers
	show_message "echo 'arp -f /etc/ethers' >> /etc/rc.d/rc.local to have arp table loaded on restarts"
}

dont_talk_with_others () {
	net_shorter="`echo $net_address | sed 's/\.0$//'`"
	for (( i=1; $i<255; i++ )); do 
		grep "$net_shorter.$i " $MAC_FILE || echo "$net_shorter.$i 00:00:00:00:00:00" >> $MAC_FILE
	done
	arp -f /etc/ethers
	show_message "Server will only talk to above IP's"
}

run_main () {
	install_if_missing dhcp
	cat ${CONF_FILE} | egrep "subnet.*$net_address.*netmask.*$netmask" && { show_message "$(nls "already defined - clear /etc/dhcpcd.conf first")"; exit; } || {
	line_replace "ddns-update-style" "ddns-update-style      none;" ${CONF_FILE}
	cat << EOF >> ${CONF_FILE}
subnet $net_address netmask $netmask {
	default-lease-time $(($lease_time*60));
	range $ip_start $ip_stop;
	option domain-name-servers $dns_address;
	option domain-name "$domain";
	option routers $route_address;
	option subnet-mask $netmask;
	option broadcast-address $broadcast_address;
	option ntp-servers $ntp_address;
	option netbios-name-servers $smb_address;
}
EOF
	}

	[ "X$ip_mac_mapping" = "Xyes" ] && { detect_mac_address; add_mac_address; }
	[ "X$dont_talk" = "Xyes" ] && dont_talk_with_others 
	/etc/rc.d/init.d/dhcpd restart || show_message "$(nls "There are some errors")";
}



gui () {
	eval `dml<< EOF
	<meta title="$(nls "DHCP service configuration")"><br>
	$(nls "Address range"): <br>
	<input id=ip_start caption="\`echo $net_address|cut -f-3 -d.\`.2" width=16> - <input id=ip_stop caption="\`echo $net_address|cut -f-3 -d.\`.10" width=16><br>
	$(nls "Assign a fixed IP address to card's MAC address") <check id=ip_mac_mapping><br>
	$(nls "Don't talk to users who change their IP's") <check id=dont_talk><br><br>
	$(nls "Time server"): <input id=ntp_address caption=ntp.task.gda.pl><br>
	DNS: <input id=dns_address caption="$dns_address,194.204.159.1" width=40><br>
	$(nls "SAMBA server"): <input id=smb_address caption=$ip_address><br>
	$(nls "Router"): <input id=route_address caption=$ip_address><br>
	-----------------------------------------------<br>
	$(nls "Address IP timeout"): <input id=lease_time width=10 caption="10"> ($(nls "minutes"))<br>
	-----------------------------------------------<br>
	\`dml_buttons Ok Anuluj Pomoc Edytuj Przywr\`
EOF`

	dml_cancel_check ${DATA_DIR}/NET/net_menu.sh
	dml_help_check ${DATA_DIR}/POMOC/README_dhcpd.txt
	dml_recover_check ${CONF_DIR}/dhcpd.conf /etc/
	dml_check_the_rest ${DATA_DIR}/NET/net_menu.sh
}



MAC_FILE=/etc/ethers
CONF_FILE="/etc/dhcpd.conf"
backup_file ${CONF_FILE}
backup_file /etc/ethers
detect_configuration
gui

#lamerand=`date +%N``date +%N`; echo $lamerand | sed "s/\(..\)\(..\)\(..\).*/\1:\2:\3:\2:\1:\3/"
