#!/bin/bash
#
# $Revision: 1.20 $, $Date: 2004/02/09 09:15:58 $
#
# GPL, mimooh at pld-linux.org
# TPSA neostrada speedtouch dla kernela 2.6

script_gen () {
	cat > /etc/rc.d/init.d/neostrada << EOF 
#!/bin/sh
# neostrada:	Neostrada speedtouch 330 USB modem service
# chkconfig:		35 15 85
# description:	Neostrada speedtouch 330 USB modem service

#Source function library.
. /etc/rc.d/init.d/functions

case "\$1" in
	start)
	if [ ! -f /var/lock/subsys/neostrada ]; then
		msg_starting "Neostrada"
		$MODULE_HANDLE
		daemon echo 
		mount none /proc/bus/usb -t usbdevfs 2>/dev/null
		modem_run -k -m -v 2 -f /usr/share/speedtouch/mgmt.o
		pppd call neostrada
		touch /var/lock/subsys/neostrada
	else
		msg_already_running "Neostrada"
	fi
	;;
	stop)
	if [ -f /var/lock/subsys/neostrada ]; then
		msg_stopping "Neostrada"
		daemon echo 
		killall -9 pppd pppoa3 
		rm -f /var/lock/subsys/neostrada
	else
		msg_not_running "Neostrada"
	fi
	;;
	restart)
	\$0 stop
	\$0 start
	exit \$?
	;;
	status)
	status neostrada
	RETVAL=\$?
	;;
	*)
	msg_usage "\$0 {start|stop|restart|status}"
	exit 3
	;;
esac

exit \$RETVAL
EOF
}

peers_neostrada() {
	backup_file /etc/ppp/peers/neostrada
	cat > /etc/ppp/peers/neostrada <<-EOF
	noauth
	usepeerdns
	noipdefault
	defaultroute
	sync
	user "$user"
	noaccomp
	nopcomp
	noccp
	holdoff 4
	persist
	maxfail 25
	EOF
}

chap_secrets() {
	backup_file /etc/ppp/chap-secrets
	cat > /etc/ppp/chap-secrets <<-EOF
	# Secrets for authentication using CHAP
	# client	server	secret			IP addresses
	$user     *       $passwd	*
	EOF
	chmod 600 /etc/ppp/chap-secrets
}

config_remove () {
	/etc/rc.d/init.d/neostrada stop 2>/dev/null
	chkconfig --level 35 neostrada off  2>/dev/null
	rm -rf /etc/rc.d/init.d/neostrada 2>/dev/null
}

run_main () {
	install_if_missing "speedtouch ppp ppp-plugin-pppoatm" || { echo "pakiet ppp-plugin-pppoatm nie jest niezbdny - wymagany tylko dla kernel_space"; }
	peers_neostrada
	chap_secrets
	[ -f /usr/share/speedtouch/mgmt.o ] || { 
		show_message "W do stacji pyt Neostrada tpsa, wykonam mount /dev/cdrom";
		mount /dev/cdrom
		mkdir -p /usr/share/speedtouch/
		cd /tmp
		tar -xvzf /media/cdrom/Linux/ThomsonST330/pliki.tar.gz
		tar -xvzf /mnt/cdrom/Linux/ThomsonST330/pliki.tar.gz
		tar -xvzf drivers/speedmgmt.tar.gz 
		cp -v mgmt/mgmt.o /usr/share/speedtouch/ && echo "udao si zainstalowa /usr/share/speedtouch/mgmt.o"
	}

	[ -f /usr/share/speedtouch/mgmt.o ] || { 
		show_message "Brak pliku /usr/share/speedtouch/mgmt.o, plik znajduje si na pycie tpsa lub pod adresem
http://www.speedtouchdsl.com/dvrreg_lx.htm (wymagana rejestracja)"
		exit 
	}

	line_replace pppoatm pppoatm /etc/modules
	line_replace cdc_acm cdc_acm /etc/modules
	line_replace ppp_synctty ppp_synctty /etc/modules
	line_replace ppp_generic ppp_generic /etc/modules
	for i in pppoatm cdc_acm ppp_synctty ppp_generic; do modprobe $i 2>/dev/null; done

	[ "X$space_driver" = "Xkernel_space" ] && { 
		MODULE_HANDLE="modprobe speedtch 2>/dev/null"
		line_replace speedtch speedtch /etc/modules
		cat >> /etc/ppp/peers/neostrada <<-EOF
		plugin "pppoatm.so"
		0.35
		EOF
	}
	[ "X$space_driver" = "Xuser_space" ]   && { 
		MODULE_HANDLE="rmmod speedtch 2>/dev/null"
		line_remove speedtch /etc/modules
		cat >> /etc/ppp/peers/neostrada <<-EOF
		pty "/usr/sbin/pppoa3 -e 1 -v 1 -m 1 -c -vpi 0 -vci 35"
		EOF
	}

	script_gen
	chmod 754 /etc/rc.d/init.d/neostrada
	chkconfig --del neostrada
	chkconfig --add neostrada
	chkconfig --level 35 neostrada on
	echo "Wyczam domyln bramk w /etc/sysconfig/network - ppp0 j utworzy"
	line_replace GATEWAY= GATEWAY= /etc/sysconfig/network
	line_replace GATEWAYDEV= GATEWAYDEV= /etc/sysconfig/network
	line_replace "nameserver" "nameserver 217.98.63.164" /etc/resolv.conf
	show_message "Uruchamiam /etc/rc.d/init.d/network stop w celu usunicia bramek, ok?"
	/etc/rc.d/init.d/network stop

	show_message "
	1. Uruchamiaj usug przez:
		/etc/rc.d/init.d/neostrada start

	2. W przypadku problemw zainstaluj syslog.rpm (syslog-ng wyrzuca mniej logw!) 
	i monitoruj logi przez:
		tail -f /var/log/messages
	Porwnaj z moim logiem:
		http://pldconf.pld-linux.org/speedtouch_log.txt

	3. Przeadowywanie usugi rednio dziaa - problemy jdra.
	Moesz mimo wszystko prbowa ale przynajmniej wypinaj modem z portu USB.
	W najgorszym wypadku musisz resetowa komputer.
	
	4. Dane dla rejestracji:
	login: rejestracja@neostrada.pl
	passwd: rejestracja
	mozilla www.rejestracja.neostrada.pl - tylko tam moesz si uda

	5. Jeeli nie chcesz neostrady automatycznie przy stracie uruchom: 
		chkconfig --del neostrada

	6. Testowanie tylko z kernelem z serii 2.6!, zobacz uname -a
	"
	exit
}

gui () {
	eval `dml<< EOF
	<meta title="TPSA neostrada Speedtouch"><br><br>

<button id=usb_hci caption="Skonfiguruj kontroler USB"><br><br>
Wyprbuj obydwa sterowniki<br>
kernel_space szybszy / user_space pewniejszy<br>

<menu hidden=1 id=space_driver_hidden>
<item id=kernel_space> przestrze jdra
<item id=user_space> przestrze uytkownika
</menu>
<br><input id=space_driver menu=space_driver_hidden width=16><br><br>
Uytkownik: <input id=user caption=rejestracja@neostrada.pl width=28><br><br>
     Haso: <input id=passwd caption=rejestracja width=18><br><br>
<br>
\`dml_buttons Ok Anuluj Pomoc Wyjcie\`
<button id=dml_delete caption="Usu konfiguracj"><br>
EOF`
	[ "X$usb_hci" = "Xyes" ] && { /usr/bin/pldconf -u -a; exec $0; }

	dml_cancel_check ${DATA_DIR}/NET/net_menu.sh
	dml_help_check ${DATA_DIR}/POMOC/README_tpsa_speedtouch.txt
	dml_check_the_rest ${DATA_DIR}/NET/net_menu.sh 

	[ "X$delete" = "Xyes" ] && { config_remove; exec ${DATA_DIR}/NET/net_menu.sh; }
}

[ -z "$1" ] && gui || run_main 2>/dev/null
