#!/bin/bash
# $Revision: 1.7 $, $Date: 2004/03/12 12:28:45 $
# GPL, mimooh at pld-linux.org, teodor at pld-linux.org

get_conf () { # parse /etc/samba/smb.conf and fill user|workgroup|desc fields
	[ -f ${CONF_FILE} ] && grep "[^#]$1" ${CONF_FILE} | perl -pe "s/.*$1 = //" 
}

run_main () {
	install_if_missing samba
	[ "X$users_can_mount" = "Xyes" ] && chmod 04755 /usr/bin/smbmnt /usr/bin/smbumount

	if [ -n "$user" ]; then
		useradd $user 1>&2 >/dev/null
		[ -n "$pass" ] && smbpasswd -a $user $pass || smbpasswd -a $user -n
	fi
	
	line_replace "\[global\]" "[global]" ${CONF_FILE}
	line_replace ".*netbios name" "	netbios name = $netbios" ${CONF_FILE}
	line_replace ".*workgroup" "	workgroup = $workgroup" ${CONF_FILE}
	line_replace ".*server string = " "	server string = $string" ${CONF_FILE}
	line_replace ".*encrypt passwords" "	encrypt passwords = yes" ${CONF_FILE}
	line_replace ".*smb passwd file" "	smb passwd file = /etc/samba/smbpasswd" ${CONF_FILE}
	line_replace ".*guest account" "	guest account = guest" ${CONF_FILE}
	line_replace ".*map to guest" "	map to guest = Bad Password" ${CONF_FILE}
	
	if [ "X$guest_ok" = "Xyes" ]; then
		public_share=yes
		useradd guest -s /bin/false 1>&2 >/dev/null
		smbpasswd -a guest -n 1>&2 >/dev/null
	else
		public_share=no
	fi
	if [ -n "$share_path" ]; then
		share_name=`basename $share_path`
		cat >> $CONF_FILE << EOF 

[$share_name]
	path = $share_path
	writable = $rw_mode
	browseable = yes
	public = $public_share
EOF
	fi
	[ "X$share_home_dir" = "Xyes" ] && {
		drop_section '\[homes\]' 'writable = yes' /etc/samba/smb.conf
		cat >> $CONF_FILE << EOF 

[homes]
	writable = yes
	browseable = no
EOF

	}

	show_verbose_message "$(nls "/etc/samba/smb.conf contents")" "cat /etc/samba/smb.conf"
	/etc/rc.d/init.d/smb restart
}

gui () {
	eval `dml<< EOF
	<meta title="$(nls "SAMBA (Neighbourhood network)")">
	<br><br>
	  <button id=clear_config caption="$(nls "Clear smb.conf")"><br><br>
	<menu id=rw_mode hidden=1>
	<item id=yes> $(nls "read/write")
	<item id=no> $(nls "read only")
	</menu>
	$(nls "Computer name"): <input id=netbios caption="$netbios" width=13> $(nls "Workgroup"): <input width=13 id=workgroup caption="$workgroup"><br>
	$(nls "Description"): <input id=string caption="$string" width=50><br>	
	--------------------------------------------------------------<br>
	$(nls "Add user"): <input id=user width=13> $(nls "Password"): <input id=pass width=13><br>
	--------------------------------------------------------------<br>
	$(nls "Share"): <input id=share_path fs=d label=$(nls "Select") width=40><br>
	<check id=guest_ok> $(nls "Everyone can use this share - password not required")<br>
	$(nls "Access mode (read/write)"): <input id=rw_mode menu=rw_mode ghosted=1 width=5><br>
	--------------------------------------------------------------<br>
	<check id=share_home_dir> $(nls "Share users' home folders")<br>
	--------------------------------------------------------------<br>
	<check id=users_can_mount> $(nls "Users can mount shares")<br>
	--------------------------------------------------------------<br>
	\`dml_buttons Ok Anuluj Pomoc Edytuj Przywr\`
EOF`;

	[ "X$clear_config" = "Xyes" ] && { echo > /etc/samba/smb.conf 1>&2 > /dev/null; exec $0; }
	dml_cancel_check ${DATA_DIR}/NET/net_menu.sh
	dml_help_check ${DATA_DIR}/POMOC/README_smb.txt
	dml_edit_check /etc/samba/smb.conf
	dml_recover_check ${CONF_DIR}/smb.conf /etc/samba/
	dml_check_the_rest ${DATA_DIR}/NET/net_menu.sh
}

CONF_FILE="/etc/samba/smb.conf"
backup_file ${CONF_FILE}

workgroup=`get_conf workgroup`
netbios=`get_conf "netbios name"`
string=`get_conf "server string"`

gui
