#!/bin/bash
# $Revision: 1.16 $, $Date: 2004/03/03 00:10:48 $
# GPL, bonder at pld-linux.org, teodor at pld-linux.org, mimooh at pld-linux.org

script_gen () {
	cat > /etc/rc.d/init.d/tfirewall << EOF 
#!/bin/sh
# tfirewall	Simple firewall with masquerade funtion for small network.
# chkconfig:	35 15 85
# description:	It creates simple firewall using iptables (2.4|2.6). Main function
#               is to create masquerade, but it also can block connection with
#               defined adress, and protect against "hajkiers'" typical attack

#Source function library.
. /etc/rc.d/init.d/functions

case "\$1" in
	start)
	if [ ! -f /var/lock/subsys/tfirewall ]; then
		msg_starting "Trivial Firewall"

		# enable IP forwarding and clear old entries 
		echo 1 > /proc/sys/net/ipv4/ip_forward
		daemon /usr/sbin/iptables -F 2>/dev/null
		/usr/sbin/iptables -F -t nat 2>/dev/null
		/usr/sbin/iptables -P FORWARD DROP 2>/dev/null

		# output rules
		/usr/sbin/iptables -t nat -A POSTROUTING -o $if_out $rule_out 2>/dev/null
		/usr/sbin/iptables -A FORWARD -o $if_out -j ACCEPT 2>/dev/null

		# input rules
		/usr/sbin/iptables -A FORWARD -i $if_out -m state --state RELATED,ESTABLISHED -j ACCEPT 2>/dev/null

		$protection_entries

		touch /var/lock/subsys/tfirewall
	else
		msg_already_running "Trivial Firewall"
	fi
	;;
	stop)
	if [ -f /var/lock/subsys/tfirewall ]; then
		msg_stopping "Trivial Firewall"
		daemon /usr/sbin/iptables -F 2>/dev/null
		/usr/sbin/iptables -t nat -F 2>/dev/null
		/usr/sbin/iptables -P FORWARD ACCEPT 2>/dev/null
		rm -f /var/lock/subsys/tfirewall
	else
		msg_not_running "Trivial Firewall"
	fi
	;;
	restart)
	\$0 stop
	\$0 start
	exit \$?
	;;
	status)
	/usr/sbin/iptables -L FORWARD -v
	/usr/sbin/iptables -L POSTROUTING -v -t nat
	status tfirewall
	RETVAL=\$?
	;;
	*)
	msg_usage "\$0 {start|stop|restart|status}"
	exit 3
	;;
esac

exit \$RETVAL
EOF

}

protection () {
	protection_entries="
		#Simple protection 
		/sbin/modprobe ipt_limit
		# Syn-flood protection
		/usr/sbin/iptables -A FORWARD -p tcp --syn --match limit --limit 1/s --limit-burst 5 -j ACCEPT
		# Furtive port scanner
		/usr/sbin/iptables -A FORWARD -p tcp --tcp-flags SYN,ACK,FIN,RST RST --match limit --limit 1/s --limit-burst 5 -j ACCEPT
		# Ping of death
		/usr/sbin/iptables -A FORWARD -p icmp --icmp-type echo-request --match limit --limit 1/s --limit-burst 5 -j ACCEPT
		# Kill malformed XMAS packets
		/usr/sbin/iptables -A INPUT -p tcp --tcp-flags ALL ALL -j DROP
		/usr/sbin/iptables -A FORWARD -p tcp --tcp-flags ALL ALL -j DROP
		# Kill malformed NULL packets
		/usr/sbin/iptables -A INPUT -p tcp --tcp-flags ALL NONE -j DROP
		/usr/sbin/iptables -A FORWARD -p tcp --tcp-flags ALL NONE -j DROP
	"
}

config_remove () {
	/etc/rc.d/init.d/tfirewall stop 2>/dev/null
	chkconfig --level 35 tfirewall off  2>/dev/null
	rm -rf /etc/rc.d/init.d/tfirewall 2>/dev/null
}

run_main () {
	if [ -z $if_out ]; then
		show_message "$( nls "External network device not set")"
	else
					install_if_missing iptables || { echo "$(nls "iptables not found")" && exit; }
		if [ -n "$ip_out" ]; then
			rule_out="-j SNAT --to $ip_out"
		else
			rule_out="-j MASQUERADE"
		fi
		script_gen
		chmod 754 /etc/rc.d/init.d/tfirewall
		chkconfig --del tfirewall
		chkconfig --add tfirewall
		chkconfig --level 35 tfirewall on
		/etc/rc.d/init.d/tfirewall restart
		show_message "$(nls "Firewall configured")"
	fi
}

gui () {
	eval `dml << EOF
	<meta title="$(nls "Simple firewall setup")"><BR>
	$(nls "External network device"): <input id=if_out width=7> np. eth0  <br><br>
	$(nls "External IP address"): <input id=ip_out width=17><br>
	$(nls "If it's empty, dynamic IP address will be used")<br><br>
	<check id=protect> $(nls "Protect against typical attack ")(Ping of Death, Syn-Flood)<br><br>
	\`dml_buttons Ok Anuluj Edytuj Pomoc\`<button id=config_remove caption="$(nls "Remove config")">
EOF`

	[ "X$config_remove" = "Xyes" ] && { config_remove; exec ${DATA_DIR}/NET/net_menu.sh; }
	[ "X$protect" = "Xyes" ] && protection
	dml_cancel_check ${DATA_DIR}/NET/net_menu.sh 
	dml_edit_check /etc/rc.d/init.d/tfirewall
	dml_help_check ${DATA_DIR}/POMOC/README_tfirewall.txt
	dml_check_the_rest ${DATA_DIR}/NET/net_menu.sh
}

gui
