#!/bin/bash
#
# fetchmail.sh	This module help you to configure fetchmailrc file
#
# Author:	Jakub Krajniak <teodor at pld-linux.org>
# Licence:	GPL
#
# $Id$
# 

CONF_FILE="$HOME_ETC/.fetchmailrc"

run_main () {
	install_if_missing mail
	if [ ! -f $CONF_FILE ]; then
		cat > $CONF_FILE << EOF
# Configuration created by pldconf - fetchmail
set postmaster "$USER"
EOF
	fi
	add_entries
	chmod 600 $CONF_FILE
}

add_entries () {
	backup_file $CONF_FILE
	cat >> $CONF_FILE << EOF

poll $server with proto $proto
user '$login' there with password '$pass' is '$USER' here
EOF
	[ "X$all_msg" = "Xyes" ] && echo "		fetchall" >> $CONF_FILE
	[ "X$keep_msg" = "Xyes" ] && echo "		keep" >> $CONF_FILE
	[ "X$flush_msg" = "Xyes" ] && echo "		flush" >> $CONF_FILE
	[ $max_size ] && { byte_size=$(($max_size*1024)); echo "		limit $byte_size" >> $CONF_FILE; }
	[ $max_count ] && echo "		fetchlimit $max_count" >> $CONF_FILE
}

gui () {

	eval `dml<< EOF
	<meta title="$(nls "fetchmail configuration")"><br>
	$(nls "Server"):   <input id=server caption=foo.com><br>
	$(nls "Login"):    <input id=login caption=penguin><br>
	$(nls "Password"): <input id=pass caption=foopass><br><br>
	$(nls "Protocol"): 
	<menu id=proto>
	<item id=auto> AUTO
	<item id=pop3> POP3
	<item id=imap> IMAP
	</menu><br>
	<check id=all_msg> $(nls "Fetch all messages")<br>
	<check id=keep_msg> $(nls "Keep messages on server")<br>
	<check id=flush_msg> $(nls "Remove old messages (dangerous)")<br><br>
	$(nls "Maximum message size"): <input id=max_size caption=1024 width=15> kB.<br><br>
	$(nls "Maximum number of messages"): <input id=max_count caption=300 width=5> <br><br>
	\`dml_buttons Ok Anuluj Pomoc Edytuj Wyjcie Przywr\`
EOF`

	dml_cancel_check ${EXEC_PREFIX}/pldconf
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
	dml_help_check ${DATA_DIR}/POMOC/README_fetchmail.txt
	dml_edit_check ${CONF_FILE}
	dml_recovery_check $HOME_ETC/.pldconf/.fetchmailrc ${CONF_FILE}

}

print_help() {
	cat << EOF
$(nls "Options"):
-s			$(nls "server name eg. pop3.mail.uk")
-l			$(nls "user login")
-p			$(nls "password")
-P			$(nls "protocol") (POP3,Auto,IMAP)
-a 			$(nls "fetch all messages from server")
-k			$(nls "keep messages on server")
-f			$(nls "remove old messages (dangerous")
-S			$(nls "maximum message size")
-c			$(nls "maximum number of messages accepted from server")
-h			$(nls "help")
$(nls "no options run GUI")
EOF
}

while getopts "s:l:p:P:akfS:c:h" opt
do
	case $opt in
		s ) server="$OPTARG";;
		l ) login="yes";;
		p ) pass="$OPTARG";;
		P ) proto="$OPTARG";;
		a ) all_msg="yes";;
		k ) keep_msg="yes";;
		f ) flush_msg="yes";;
		S ) max_size="$OPTARG";;
		c ) max_count="$OPTARG";;
		h ) print_help; exit;; 
		? ) print_help; exit;; 
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
