#!/bin/bash
# 
# mutt.sh	This module will configure your muttrc file
# 
# Author:	Jakub Krajniak <teodor at pld-linux.org>
# Licence:	GPL
#
# $Id$
#

FILE_CONF="$HOME_ETC/.muttrc"
DIR_CONF="$HOME_ETC/.mutt"

mail_convert () {
	MAIL_LOGIN=`echo $1 | cut -f1 -d@`
	MAIL_DOMAIN=`echo $1 | cut -f2 -d@`
	[ ! -f ${FILE_CONF} ] && echo "$MAIL_LOGIN@$MAIL_DOMAIN";
	[ -f ${FILE_CONF} ] && echo "$MAIL_LOGIN\@$MAIL_DOMAIN";
}

gpg_set () {
	if [ "X$gpg_check" = "Xyes" ]; then
		install_if_missing gnupg
		cat > ${DIR_CONF}/gpg.rc << EOF
set pgp_decode_command="/usr/bin/gpg   %?p?--passphrase-fd 0? --no-verbose --quiet  --batch  --output - %f"
set pgp_verify_command="/usr/bin/gpg   --no-verbose --quiet  --batch  --output - --verify %s %f"
set pgp_decrypt_command="/usr/bin/gpg   --passphrase-fd 0 --no-verbose --quiet  --batch  --output - %f"
set pgp_sign_command="/usr/bin/gpg    --no-verbose --batch --quiet   --output - --passphrase-fd 0 --armor --detach-sign --textmode %?a?-u %a? %f"
set pgp_clearsign_command="/usr/bin/gpg   --no-verbose --batch --quiet   --output - --passphrase-fd 0 --armor --textmode --clearsign %?a?-u %a? %f"
set pgp_encrypt_only_command="pgpewrap /usr/bin/gpg    --batch  --quiet  --no-verbose --output - --encrypt --textmode --armor --always-trust -- -r %r -- %f"
set pgp_encrypt_sign_command="pgpewrap /usr/bin/gpg  --passphrase-fd 0  --batch --quiet  --no-verbose  --textmode --output - --encrypt --sign %?a?-u %a? --armor --always-trust -- -r %r -- %f"
set pgp_import_command="/usr/bin/gpg  --no-verbose --import -v %f"
set pgp_export_command="/usr/bin/gpg   --no-verbose --export --armor %r"
set pgp_verify_key_command="/usr/bin/gpg   --verbose --batch  --fingerprint --check-sigs %r"
set pgp_list_pubring_command="/usr/bin/gpg   --no-verbose --batch --quiet   --with-colons --list-keys %r" 
set pgp_list_secring_command="/usr/bin/gpg   --no-verbose --batch --quiet   --with-colons --list-secret-keys %r" 
set pgp_good_sign="\`gettext -d gnupg -s 'Good signature from "' | tr -d '"'\`"
EOF
		line_replace "set pgp_autoselectkey" "set pgp_autoselectkey=yes" ${FILE_CONF}	
		line_replace "set pgp_autosign" "set pgp_autosign=yes" ${FILE_CONF}
		line_replace "set pgp_verify_sig" "set pgp_verify_sig=yes" ${FILE_CONF}
		line_replace "source '${DIR_CONF}/gpg.rc'" "source '${DIR_CONF}/gpg.rc'" ${FILE_CONF} 
	else
		line_replace "set pgp_autoselectkey" "set pgp_autoselectkey=no" ${FILE_CONF}	
		line_replace "set pgp_autosign" "set pgp_autosign=no" ${FILE_CONF}
		line_replace "set pgp_verify_sig" "set pgp_verify_sig=no" ${FILE_CONF}
		line_remove "gpg.rc" ${FILE_CONF}
	fi
}

color_set () {
	cat > ${DIR_CONF}/colors << EOF
color attachment brightmagenta default
color body magenta default "[ a-z_0-9.]+@[ a-z_0-9.]+"
color body magenta default "[ a-z_0-9.]+@[ a-z_0-9.]+"
color header brightred default ^(From|Subject):
color quoted brightblue default
color signature red default
color error brightred default
color indicator brightyellow blue
color status yellow blue
color tree yellow default
color normal white default
color hdrdefault brightblue default
color body magenta default "[ a-z_0-9.]+@[ a-z_0-9.]+"
color body magenta default "[ a-z_0-9.]+@[ a-z_0-9.]+"
color body magenta default "[ a-z_0-9.]+@[ a-z_0-9.]+"
color body brightyellow default "(ftp|http)://[^ ]+"
EOF
}

conf_rest () {
	color_set
	line_replace "source $HOME_ETC/.mutt/colors" "source $HOME_ETC/.mutt/colors" ${FILE_CONF}
	line_replace "set mailcap_path" "set mailcap_path=\"/etc/mailcap\"" ${FILE_CONF}
	line_replace "set index_format" "set index_format=\"%4C/%m %Z %{%d %b} %-22.20L %s %> %Y\"" ${FILE_CONF}
	line_replace "ignore" "ignore *" ${FILE_CONF}
	line_replace "unignore" "unignore Date: Subject: From: To:" ${FILE_CONF}
	line_replace "set status_format" "set status_format=\":-: %f <[Wiad: %m Nowe: %n | nieczytanych: %u> %> %P\"" ${FILE_CONF}
}

run_main () {
	install_if_missing mutt
	mkdir -p ${DIR_CONF}
	backup_file ${FILE_CONF}
	email=`mail_convert $email`
	replymail=`mail_convert $replymail`
	line_replace "set from" "set from=\"$name <$email>\"" ${FILE_CONF}
	line_replace "set charset" "set charset=\"$charset\"" ${FILE_CONF}
	line_replace "set send_charset" "set send_charset=\"iso8859-2:us-ascii:utf-8\"" ${FILE_CONF}
	line_replace "my_hdr Reply-To" "my_hdr Reply-To: $name <$replymail>" ${FILE_CONF}
	line_replace "set sort" "set sort=$sort_style" ${FILE_CONF}
	line_replace "set attribution" "set attribution=\"$remessage\"" ${FILE_CONF}
	gpg_set
	line_replace "mailboxes" "mailboxes 'echo $maildir/*'" ${FILE_CONF} 
	line_replace "set postponed" "set postponed=\"$maildir/postponed\"" ${FILE_CONF} 
	line_replace "set record" "set record=\"$maildir/record\"" ${FILE_CONF} 
	line_replace "set mbox" "set mbox=\"$maildir/mbox\"" ${FILE_CONF} 
	
	if [ "X$vim_check" = "Xyes" ]; then
		line_replace "set editor" "set editor=\"vim -c 'set tw=72'\"" ${FILE_CONF}
	else
		line_remove "set editor" ${FILE_CONF}
	fi
	conf_rest
}


gui ()  {
	eval `dml<< EOF
	<meta title="$(nls "Mutt setup")"><br>
	<menu id=sorting hidden=1>
	<item id=date> $(nls "date")
	<item id=from> $(nls "from")
	<item id=score> $(nls "score")
	<item id=size> $(nls "size")
	<item id=subject> $(nls "subject")
	<item id=threads> $(nls "threads")
	<item id=to> $(nls "to")
	</menu>
	<menu id=chartable hidden=1>
	<item id=iso8859-2> ISO8859-2
	<item id=utf-8> UTF-8
	<item id=us-ascii> US-ASCII
	</menu>
	$(nls "Name or nick"): <input id=name caption="$name" width=20><br><br>
	$(nls "e-mail address"):  <input id=email caption="$email" width=15> 
	$(nls "reply address")	: <input id=replymail caption="$replymail" width=15><br><br>
	$(nls "Sort mode"): <input id=sort_style menu=sorting ghosted=1 width=7 caption="$sort_style"> 
	$(nls "Charset"): <input id=charset menu=chartable ghosted=1 width=7 caption="$charset"><br><br>
	$(nls "Reply header"): <br> <input id=remessage caption="$remessage"> 
	<button id=specialchar caption="$(nls "Special marks")"> <br><br>
	<check id=gpg_check checked=$gpg_check> $(nls "Use GPG to sign/encrypt message") <br>
	<check id=vim_check checked=$vim_check> $(nls "Wrapping lines after 72 chars") (Vim)<br> <br>
	/home/users/$USER/<input id=maildir width=10 caption=$maildir> $(nls "mailbox director")<br><br>
	\`dml_buttons Ok Anuluj Pomoc Przywr Edytuj Wyjcie\`
EOF`

	[ "X$specialchar" = "Xyes" ] && { $PLDCONF_PAGER -pZnaki ${DATA_DIR}/POMOC/README_mutt.txt; exec $0; }
	dml_cancel_check ${EXEC_PREFIX}/pldconf
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
	dml_help_check ${DATA_DIR}/POMOC/README_mutt.txt
	dml_edit_check ${FILE_CONF}
	dml_recover_check $HOME_ETC/.pldconf/.muttrc ${HOME_ETC}
}
#############
#Defaults :)),
name="$USER Lenon"
email="$USER@foo.com"
replymail="$USER@foo.com"
sort_style="threads"
charset="iso8859-2"
remessage="On %d, %n said:"
maildir=Mail
gpg_check=0
vim_check=1
###########
gui
