#!/bin/bash
# $Revision: 1.9 $, $Date: 2004/03/10 20:15:59 $
# GPL, mimooh at pld-linux.org, teodor at pld-linux.org

Xconfigured="$HOME/xorg.conf.new"    # X -configure generates this one
X_CONF_FILE="/etc/X11/xorg.conf"

[ -f "/tmp/.X0-lock" ] && { echo "$(nls "Found /tmp/.X0-lock, Xserwer running?")"; exit; }
grep `hostname` /etc/hosts 1>&2 >/dev/null || show_message "$(nls "Set hostname in /etc/hosts: pldconf -> Network")"

get_resolution () {
	case $resolution_ in
		640x480) resolution='"640x480"';;
		800x600) resolution='"800x600" "640x480"';;
		1024x768) resolution='"1024x768" "800x600" "640x480"';;
		1280x1024) resolution='"1280x1024" "1024x768" "800x600" "640x480"';;
		1600x1200) resolution='"1600x1200" "1280x1024" "1024x768" "800x600" "640x480"';;
	esac
}

get_refresh () {
	case $refresh_ in
		60) refresh='Vertrefresh  50-65';;
		70) refresh='Vertrefresh  50-80';;
		85) refresh='Vertrefresh  50-90';;
	esac
	[ -n "$refresh" ] && horizsync="Horizsync    30-80 #$(nls "Be careful with this VertRefresh and HorizSync settings")"
}

run_main() {
	install_if_missing X11-Xserver  
	backup_file $X_CONF_FILE
	[ "X$fix_agp" = "Xyes" ] && pci_dev agp
	X -configure 2>/dev/null
	drop_section 'Section "InputDevice"' 'EndSection'  $Xconfigured
	drop_section 'Section "Screen"' 'EndSection' $Xconfigured
	drop_section 'Section "Monitor"' 'EndSection' $Xconfigured 
	line_replace 'Section "Files"' 'Section "Files"\n\tFontPath     "/usr/share/fonts/TTF/WIN32/"' $Xconfigured 
	line_replace 'Section "Module"' 'Section "Module"\n\tLoad  "freetype"' $Xconfigured 
	get_resolution
	get_refresh
	cat >> $Xconfigured << EOF
Section "Screen"
	Identifier "Screen0"
	Device     "Card0"
	Monitor    "Monitor0"
	DefaultDepth  $depth
	SubSection "Display"
		Depth  $depth   
		Modes  $resolution
	EndSubSection
EndSection

Section "Monitor"
	Identifier   "Monitor0"
	VendorName   "Monitor Vendor"
	ModelName    "Monitor Model"
	$refresh
	$horizsync 
EndSection

Section "InputDevice"
	Identifier  "Keyboard0"
	Driver      "kbd"
	Option "XkbRules"	"xfree86"
	Option "XkbModel"	"pc105"
	Option "XkbLayout"	"pl"
EndSection

Section "InputDevice"
	Identifier  "Mouse0"
	Driver      "mouse"
	Option "Emulate3Buttons"
	Option "Device" "/dev/mouse"
	Option "Protocol" "$X_MOUSE_PROTOCOL"
	Option "Buttons" "7"
	Option "ZAxisMapping" "4 5 6 7"
EndSection
EOF
	cp $Xconfigured $X_CONF_FILE
}

gui() {
	eval `dml << EOF
	<meta title="$(nls "X11 setup")">
	$(nls "Mouse"):<br>
	<button id=dml_mouse_conf caption=$X_MOUSE_PROTOCOL><br><br>
	$(nls "Screen resolution"):
	<menu id=resolution_ height=3> 
	<item id=640x480> 640x480
	<item id=800x600> 800x600
	<item id=1024x768> 1024x768
	<item id=1280x1024> 1280x1024
	<item id=1600x1200> 1600x1200
	</menu>
	<br>
	$(nls "Color depth"):
	<menu id=depth>
	<item id=8> $(nls "8 bits")
	<item id=16> $(nls "16 bits")
	<item id=24> $(nls "24 bits")
	</menu>
	<br>
	$(nls "Refresh rate"):
	<menu id=refresh_ height=3>
	<item id=auto> auto
	<item id=60> 60 Hz  
	<item id=70> 70 Hz
	<item id=85> 85 Hz  
	</menu>
	<br>
	<check  id=fix_agp> $(nls "Load agp module")<br>
	\`dml_buttons Ok Anuluj Edytuj Pomoc Przywr\`<br>
EOF`

	[ "X$dml_mouse_conf" = "Xyes" ] && exec ${DATA_DIR}/DEVICES/mouse.sh -x -G
	dml_cancel_check ${DATA_DIR}/X/X_menu.sh
	dml_edit_check $X_CONF_FILE 
	dml_help_check ${DATA_DIR}/POMOC/README_X.txt
	dml_recover_check ${CONF_DIR}/xorg.conf $X_CONF_FILE 
	dml_check_the_rest ${DATA_DIR}/X/X_menu.sh
}

command_help () {
	cat << EOF
 -r $(nls "resolution: 640x480/800x600/1024x768/1280x1024/1600x1200 pikxels")
 -c $(nls "colors: 8/16/24 bits")
 -f $(nls "refresh rate: 60/70/75/85/no=auto Hz")
 -h $(nls "help")
 $(nls "mouse setup is in pldconf -> Devices -> Mouse")

EOF
}

while getopts "r:c:f:h" opt 
do
	case $opt in
		r) resolution_="$OPTARG"; get_resolution;;
        	c) depth="$OPTARG";; 
		f) refresh_="$OPTARG"; get_refresh;;
		h) command_help; exit;;
		*) command_help; exit;;
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
