#!/bin/bash
# $Revision: 1.26 $, $Date: 2003/11/06 11:28:32 $
# GPL, mimooh at pld-linux.org

run_main() {
	[ "X$beeper_off" = "Xyes" ] && xclients_entry="xset b 0 0 0\n"
	[ -z "$chosen_env" ] && chosen_env="mimoohowy"

	case $chosen_env in
		mimoohowy)
		install_if_missing "FreeIconsProject rox xfwm4 xfdesktop xfce4-panel xfce4-minicmd-plugin xfcalendar xfce4-datetime-plugin xfce4-windowlist-plugin xfce4-weather-plugin xfce4-mixer xfce4-clipman-plugin gimp xchat gg2-plugin-jabber gg2-emoticons gg2-plugin-gui-gtk+2 gg2-plugin-gadu-gadu multi-gnome-terminal gkrellm mplayer inkscape";
		archive=${DATA_DIR}/X/archive/mimoohowy.tgz
		xclients_entry="$xclients_entry xrdb -remove\nxfce4-panel &\ngkrellm &\nrox -p=2\nexec xfwm4\n";;

		teodorowy) #for teodor
		install_if_missing "WindowMaker"
		archive=${DATA_DIR}/X/archive/teodorowy.tgz
		xclients_entry="$xclients_entry xapm &\nxclock -digital -update 1 &\nexec wmaker\n";;

		xfwm4)
		install_if_missing "xfwm4 xfce4-panel xfce-utils xfce4-mixer xfdesktop xffm"
		xclients_entry="$xclients_entry xfce4-panel &\nxfdesktop &\nexec xfwm4\n";;

		wmaker)
		install_if_missing "WindowMaker" 
		xclients_entry="$xclients_entry exec wmaker\n";;

		icewm)
		install_if_missing "icewm" 
		xclients_entry="$xclients_entry exec icewm\n";;

		fluxbox)
		install_if_missing "fluxbox" 
		xclients_entry="$xclients_entry exec fluxbox\n";;

		afterstep)
		install_if_missing "afterstep" 
		xclients_entry="$xclients_entry exec afterstep\n";;

		gnome)
		install_if_missing "gnome-desktop gnome-themes gnome-session gnome-panel nautilus metacity metacity-themes-Simple metacity-themes-Atlanta metacity-themes-Crux metacity-themes-Metabox metacity-themes-AgingGorilla"
		xclients_entry="$xclients_entry exec gnome-session\n";;

		kde)
		install_if_missing "kdebase" 
		xclients_entry="$xclients_entry exec startkde\n";;
	esac

	[ -n "$install_for_user" ] && create_entries 
	[ -n "$install_for_group" ] && group_install
}

group_install() {
	group_gid=`getent group | grep $install_for_group: | cut -d: -f3`
	[ -z "$group_gid" ] && { show_message "$install_for_group: $(nls "group doesn't exist")"; exit; }
	for i in `getent passwd | grep $group_gid`; do
		install_for_user=`echo $i | cut -d: -f1`
		create_entries 2>/dev/null
	done
}

get_cursors () {
	ls -d /usr/share/icons/*/cursors 2>/dev/null | sed -e 's,/usr/share/icons/,,;s,/cursors,,' \
	| while read item; do 
		echo "<item id=$item> $item" 
	done
	echo "<item id=standard> standard"
}

create_entries() {
	group_name=`id -n -g $install_for_user`
	homedir=`getent passwd | grep ^$install_for_user: | cut -d: -f 6 | head -1` #head -1 for grep root
	[ -z "$homedir" ] && { show_message "$install_for_user: $(nls "can't find home dir")"; exit; }
	echo; echo; echo
	echo "$install_for_user :: $homedir"
	echo; echo; echo
	sleep 1

	[ -n "$terminal_font" ] && set_terminal
	[ -n "$gtk_font" ] && set_gtk_font
	line_replace "Xcursor.theme:" "Xcursor.theme:$cursor_theme" $homedir/.Xdefaults
	line_replace 'alias  ls="ls --color=tty"' 'alias  ls="ls --color=tty"' $homedir/.bashrc 
	printf "$xclients_entry" > $homedir/.Xclients; chmod 755 $homedir/.Xclients; rm $homedir/.xinitrc
	[ -n "$archive" ] && { show_verbose_message "$archive :: $homedir"; tar xvvzf $archive -C $homedir; }

	if [ `id -nu` = root ]; then
		echo "chown -R $install_for_user $homedir & chgrp -R $group_name $homedir ..."
		chown -R $install_for_user $homedir;  chgrp -R $group_name $homedir 
	fi
}

set_gtk_font() {
	cat <<- EOF > $homedir/.gtkrc-2.0
	gtk-key-theme-name = "Emacs"
	gtk-can-change-accels = 1
	style "user-font"
	{
		font_name="sans $gtk_font"
	}
	widget_class "*" style "user-font"
	EOF
}

set_terminal() {
	cat <<- EOF > $homedir/.Xdefaults
	xterm*foreground: $terminal_fg
	xterm*background: $terminal_bg 
	xterm*font: -misc-fixed-medium-r-*-*-$terminal_font-*-*-*-*-*-iso8859-2
	aterm*foreground: $terminal_fg
	aterm*background: $terminal_bg
	aterm*font: -misc-fixed-medium-r-*-*-$terminal_font-*-*-*-*-*-iso8859-2
	EOF
}

gui() {
	eval `dml << EOF
	<meta title='Desktop'><br>
	<menu id=env_hidden hidden=1 height=9>
	<item id='mimoohowy'> mimoohowy
	<item id='teodorowy'> teodorowy
	<item id='xfwm4'> xfwm4
	<item id='wmaker'> wmaker
	<item id='icewm'> icewm
	<item id='fluxbox'> fluxbox
	<item id='afterstep'> afterstep
	<item id='gnome'> gnome
	<item id='kde'> kde
	</menu>

	<menu id=terminal_colors_hidden hidden=1 height=6>
	<item id='green'> green
	<item id='black'> black
	<item id='white'> white
	<item id='red'> red
	<item id='wheat'> wheat
	<item id='blue'> blue
	</menu>

	<menu id=cursors_hidden hidden=1>
	\`get_cursors\`
	</menu>

	Desktop<br>
	<input id=chosen_env caption=mimoohowy menu=env_hidden width=10 label="desktop"><br><br>

	Terminal (aterm/xterm)<br>
	<input id=terminal_fg menu=terminal_colors_hidden width=10 caption=green label=$(nls "Foreground")>   
	<input id=terminal_bg menu=terminal_colors_hidden width=10 caption=black label=$(nls "Background")>
	  $(nls "Font size") <input id=terminal_font width=4><br><br>

	$(nls "GTK+ font") (rox/gimp...)<br>
	$(nls "Font size") <input id=gtk_font width=4><br><br>

	<check id=beeper_off > $(nls "Turn beeper off")<br><br>

	$(nls "Xcursors")<br>
	<button id=install_cursors caption="$(nls "Install themes")">
	  <input id=cursor_theme caption=standard menu=cursors_hidden width=10 label="$(nls "Xcursor theme")"><br><br><br>

	$for_which_user

	<br><br>
	\`dml_buttons Ok Anuluj Pomoc Wyjcie\`<br>
EOF`

	[ "X$install_cursors" = "Xyes" ] && install_if_missing XcursorTheme*
	dml_cancel_check $where_to_go
	dml_help_check ${DATA_DIR}/POMOC/README_desktop.txt 
	dml_check_the_rest $where_to_go
	return 0
}

command_help() {
	cat <<- EOF
	usage: /usr/share/pldconf/X/desktop.sh [options]
	no options start graphical configurator 
	-m <environment> (mimoohowy/teodorowy/xfwm4/wmaker/icewm/fluxbox/afterstep/gnome/kde) 
	-F <fg_color> terminal foreground color 
	-B <bg_color> terminal background color
	-T <terminal font> 
	-f <gtk font> 
	-v turns beeper off
	-u <for user>, only root can set this
	-g <for group>, only root can set this
	example:
	/usr/share/pldconf/X/desktop.sh -m xfwm4 -f 11 -v 0 
	EOF
}

while getopts "m:F:B:T:f:vu:g:h" opt
do
	case $opt in
		m ) chosen_env=$OPTARG;;
		F ) terminal_fg=$OPTARG;; 
		B ) terminal_bg=$OPTARG;; 
		T ) terminal_font=$OPTARG;;
		f ) gtk_font=$OPTARG;;
		v ) beeper_off="yes";;
		u ) install_for_user=$OPTARG;; 
		g ) install_for_group="$OPTARG";;
		h ) command_help; exit;;
		? ) command_help; exit;; 
	esac
done

if [ `id -nu` != root ]; then
	install_for_user=`id -nu` 
	unset install_for_group
	for_which_user="$(nls "Changing desktop for user $install_for_user")"
	where_to_go=${EXEC_PREFIX}/pldconf
else
	for_which_user="$(nls "Install for user <input id=install_for_user width=15> for group <input id=install_for_group width=15>")"
	where_to_go=${DATA_DIR}/X/X_menu.sh
fi

[ -z "$1" ] && gui || run_main 2>/dev/null
