#!/bin/bash
# $Id$
# GPL, teodor, kiniu, mimooh 

detect_win32_core() {
	mount /mnt/$letter
	ls /mnt/$letter | grep -i io.sys 2>/dev/null && {
	line_replace "export WIN32_CORE_DISK" "export WIN32_CORE_DISK=$disk" ${CONF_DIR}/ustawienia;
	line_replace "export WIN32_CORE_LETTER" "export WIN32_CORE_LETTER=$letter" ${CONF_DIR}/ustawienia;
	export WIN32_CORE_DISK=$disk WIN32_CORE_LETTER=$letter
	}
}

create_win32_entries () {

	umount -a -t vfat,ntfs
	mount | egrep 'vfat|ntfs' && { mount; show_message "$(nls "umount all vfat and ntfs patitions")"; mount; exit; }

	[ "X$auto_mount_win32" = "Xyes" ] && auto_mount=auto || auto_mount=noauto
	[ "X$ntfs_rw" = "Xyes" ] && ntfs_mode=rw || ntfs_mode=ro

	OLDIFS="$IFS" # standard fields separator is space|tab|newline; for j in fdisk we want
	IFS=$'\n'     # to treat whole line as one filed, so we choose newline only

	unset WIN32_CORE_DISK
	next_letter=1
	letters_set="cdefghijklmnoprstuwyz"
	for i in /proc/ide/hd* sda; do
		grep cdrom /proc/ide/`basename $i`/media 2>/dev/null && continue 
		unset dyski 
		for j in `fdisk -l /dev/\`basename $i\` | egrep 'FAT|NTFS'`; do
			access_mode=rw
			letter=`echo $letters_set | cut -b $next_letter`
			let next_letter++
			disk=`echo $j | cut -f1 -d' '`
			echo $j | grep FAT && part_type=vfat || { part_type=ntfs; access_mode=$ntfs_mode; }
			mkdir -p /mnt/$letter
			line_replace "$disk" "$disk	/mnt/$letter	$part_type	$auto_mount,user,iocharset=iso8859-2,umask=0,$access_mode 0 0" /etc/fstab
			[ -z "$WIN32_CORE_DISK" ] && detect_win32_core
		done
	done
	[ -z "$WIN32_CORE_DISK" ] && {
	line_replace "export WIN32_CORE_DISK" "export WIN32_CORE_DISK='-'" ${CONF_DIR}/ustawienia;
	line_replace "export WIN32_CORE_LETTER" "export WIN32_CORE_LETTER='-'" ${CONF_DIR}/ustawienia;
	export WIN32_CORE_DISK='-' WIN32_CORE_LETTER='-'
	}
	IFS="$OLDIFS"

	if [ "X$win32_ttf" = "Xyes" ]; then
		if [ ! "$WIN32_CORE_LETTER" = "-" ]; then
			install_if_missing "fontpostinst freetype XFree86" 
			mkdir -p /usr/share/fonts/TTF/WIN32
			echo "$(nls "Copying fonts from windows.....")"
			mount /mnt/$WIN32_CORE_LETTER
			cp -v /mnt/$WIN32_CORE_LETTER/{WINDOWS,WIN32,WINNT,windows,win32,winnt}/{FONTS,Fonts,fonts}/{*.TTF,*.ttf} /usr/share/fonts/TTF/WIN32/ 
			fontpostinst TTF /usr/share/fonts/TTF/WIN32
		else
			show_message "$(nls "Windows partition not found")"
		fi
	fi
}

run_main()
{
	backup_file /etc/fstab
	[ "X$win32_entries" = "Xyes" ] && create_win32_entries

	if [ $swap ]; then
		mkswap $swap
		swapon $swap
		line_replace "$swap" "$swap	swap	swap	defaults 0 0" /etc/fstab
	fi

	if [ $hdparm_disk ]; then
		install_if_missing hdparm
		hdparm_disk=`basename $hdparm_disk`
		line_replace "HDPARM_$hdparm_disk=" "HDPARM_$hdparm_disk=\"-qc 3 -qm 16 -qu 1 -qW 1 -qd 1 -qa 32 -qA 1 -qk 1 -qX 68\"" /etc/sysconfig/hdparm
		hdparm -c3 -m16 -u1 -W1 -d1 -a32 -A1 -k1 -X68 /dev/$hdparm_disk
	fi
	#Fixing possibly wrong link to /dev/cdrom or floppy entry
	if [ "X$cd_floppy_problem" = "Xyes" ]; then
		for i in /proc/ide/hd*; do
			if [ "`grep cdrom $i/media`" ]; then
				CDROM=/dev/`basename $i`
				echo "CDROM: $CDROM"
				ln -sf $CDROM /dev/cdrom$n
				show_verbose_message "$(nls "Creating symlink: ln -sf $CDROM /dev/cdrom$n")" "ls -l /dev/cdrom$n"
				line_replace ".*/media/cdrom$n" "/dev/cdrom$n	/media/cdrom$n	iso9660	noauto,mode=0444,ro,users,unhide 0 0" /etc/fstab
				mkdir -p /media/cdrom$n
				let n++
			fi
		done
		if [ "`grep CD-ROM /proc/scsi/scsi`" ]; then
			CDROM=/dev/scd0
			echo "CDROM: $CDROM"
			ln -sf $CDROM /dev/cdrom$n
			show_verbose_message "$(nls "Creating symlink: ln -sf $CDROM /dev/cdrom$n")" "ls -l /dev/cdrom$n"
			line_replace ".*/media/cdrom$n" "/dev/cdrom$n	/media/cdrom$n	iso9660	noauto,mode=0444,ro,users,unhide 0 0" /etc/fstab
			mkdir -p /media/cdrom$n
		fi
		#This is used in rox desktop to show icons for cdroms
		line_replace "/dev/fd0" "/dev/fd0	/media/floppy	vfat	noauto,users,iocharset=iso8859-2,rw,umask=0 0 0" /etc/fstab
		mkdir -p /media/floppy
	fi
	[ ! -z $cd_device ] && {
					cdrom_name="`echo $cd_device | cut -f3 -d/`";
					[ -z $cd_speed ] && line_remove "HDPARM_$cdrom_name" /etc/sysconfig/hdparm || {
					install_if_missing hdparm;
					line_replace "HDPARM_$cdrom_name" "HDPARM_$cdrom_name=\"-E $cd_speed\"" /etc/sysconfig/hdparm;
					mount | grep $cdrom_name
					[ $? -eq 0 ] && show_message "$(nls "You have to umount $cd_device and next run:") hdparm -E $cd_speed $cd_device" || hdparm -E $cd_speed $cd_device;
					}
	}
}

find_cdroms() {
		for i in `find /dev/ -name cdrom* -type l`; do
						echo "<item id=$i> $i"
		done
}

gui ()
{
	eval `dml << EOF
	<meta title="$(nls "Disk/filesystems options")" ><br><br>
	<menu id=cdroms hidden=1>
	\`find_cdroms\`
	</menu>
	$(nls "Windows partitions")<br><br>
	<check id=win32_ttf> $(nls "Install windows fonts (ca. 20MB)")<br>
	<check id=auto_mount_win32> $(nls "Mount windows partitions on start")<br>
	<check id=ntfs_rw> $(nls "NTFS in rw mode (experimental)")<br><br>
	<button id=win32_entries caption="$(nls "Configure windows partitions")"><br>
	------------------------------------------------------------------<br>
	$(nls "Set up swap partition on:") <input id=swap width=12> ($(nls "e.g. /dev/hda5"))<br>
	------------------------------------------------------------------<br>
	$(nls "Optimalization for:") <input id=hdparm_disk width=12> ($(nls "e.g. /dev/hda")) <br>
	------------------------------------------------------------------<br>
	<check id=cd_floppy_problem> $(nls "Set up CD-ROM and floppy (problems with mounting)")<br>
	$(nls "Device") <input id=cd_device menu=cdroms width=12><br>
	    $(nls "Set CDROM speed"): <input id=cd_speed width=5>x ($(nls "none -> max speed"))<br>
	------------------------------------------------------------------<br>
	\`dml_buttons Ok Anuluj Edytuj Pomoc Przywr Wyjcie\`
EOF`

	[ "X$win32_entries" = "Xyes" ] && dml_ok=yes
	dml_cancel_check /usr/bin/pldconf
	dml_recover_check ${CONF_DIR}/fstab /etc/fstab
	dml_edit_check /etc/fstab
	dml_help_check ${DATA_DIR}/POMOC/README_filesystems.txt
	dml_check_the_rest /usr/bin/pldconf
}

print_help () {
	cat << EOF
$(nls "Options:")
-a			$(nls "autoconfiguration")
-w			$(nls "NTFS partition in rw mode (dangerous)")
-m			$(nls "auto mount on start")
-f 			$(nls "install ttf fonts from windows")
-s $(nls "<partition>		set up swap on partition (e.g. /dev/hda5)")
-o $(nls "<disk>  	enable optimalization for disk e.g. /dev/hda")
-c			$(nls "set up CD-ROM and floppy")
-h -?		$(nls "help")
EOF

}


while getopts "awms:o:cfh" opt
do
	case $opt in
		a) win32_entries=yes;;
		w) ntfs_rw=yes; win32_entries=yes;;
		m) auto_mount_win32=yes; win32_entries=yes;;
		f) win32_ttf=yes;;
		s) swap="$OPTARG";;
		o) hdparm_disk="$OPTARG";;
		c) cd_floppy_problem=yes;;
		h) print_help; exit;;
		*) print_help; exit;;
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
