#!/bin/bash 
# 
# inne.sh	This module help you to configure some useful options
#		for beginer users
#
# Author:	Karol Kreski <mimooh at pld-linux.org>
# Changes:	Jakub Krajniak <teodor at pld-linux.org>
# Licence:	GPL
#
# $Id:$
#


run_main()
{
	[ -n "$date" ] && {
		line_replace "UTC" "UTC=false" /etc/sysconfig/clock #I bet I screw up the config
		line_replace "ARC" "ARC=false" /etc/sysconfig/clock
		line_replace "SRM" "SRM=false" /etc/sysconfig/clock
		date $date
		clock --systohc
	}

	[ "X$time_sync" = "Xyes" ] && {
		install_if_missing rdate 
		cat > /etc/sysconfig/rdate << EOF
SET_TIME="yes"
SYNC_HWCLOCK="yes"
RDATE_SERVERS="time.task.gda.pl ntp0.fau.de time.nrc.ca"
EOF
		show_verbose_message "$(nls "After changes in /etc/sysconfig/rdate")" "cat /etc/sysconfig/rdate"
		/etc/rc.d/init.d/rdate restart
	}

	[ -n "$lang" ] && line_replace "LANG" "LANG=$lang" /etc/sysconfig/i18n

	[ "X$sudo_nopass" = "Xyes" ] && {
		install_if_missing sudo
		backup_file /etc/sudoers
		echo 'root	ALL=(ALL) ALL' > /etc/sudoers
		echo '%wheel	ALL=(ALL) ALL' >> /etc/sudoers
		echo '%wheel	ALL=(ALL) NOPASSWD: ALL' >> /etc/sudoers
		chmod 440 /etc/sudoers
		show_verbose_message "$(nls "After changes in /etc/sudoers")" "cat /etc/sudoers"
	}

	[ "$users_to_sudo_group" ] && {
		install_if_missing sudo
		for i in $users_to_sudo_group; do
			add_user_to_group $i wheel
		done
	}

	[ -n "$beeper_volume" ] && {
		line_replace "BEEP_LENGTH" "BEEP_LENGTH=$beeper_volume" /etc/sysconfig/console
		show_message "$(nls "run /etc/rc.d/init.d/console restart to apply changes")"
	}
	[ "X$init" = "Xrestart" ] && {
		line_replace "ca::ctrlaltdel" "ca::ctrlaltdel:/sbin/shutdown -t3 -r now" /etc/inittab 
		init q
	}

	[ "X$init" = "Xshutdown" ] && {
		line_replace "ca::ctrlaltdel" "ca::ctrlaltdel:/sbin/shutdown -t3 -h now" /etc/inittab 
		init q
	}

	[ "X$halt_and_off" = "Xyes" ] && install_if_missing acpid && /etc/rc.d/init.d/acpid start
	
	[ "X$system_editor" = "Xyes" ] && {
		backup_file /etc/profile
		line_replace "export EDITOR" "export EDITOR=$editor" /etc/profile
		export EDITOR
	}

	[ "X$system_logs" = "Xyes" ] && {
		install_if_missing syslog-ng
		line_replace ".*destination console_all" "destination console_all { file(\"/dev/tty12\"); };" /etc/syslog-ng/syslog-ng.conf
		line_replace ".*log { source.* .*console_all.*" "log { source(src); destination(console_all); };" /etc/syslog-ng/syslog-ng.conf
	}
	
	[ "X$updatedb" = "Xyes" ] && {
		install_if_missing slocate;
		echo "$(nls "Update files database (for searching)...")";
		updatedb 2>/dev/null;
	}

}

gui2()
{
	eval `dml<< EOF
	<meta title="$(nls "Other (more)")" width=72><br>
	$(nls "Poweroff motherboard after shutdown") <check id=halt_and_off checked=0><br>
	------------------------------------------------------------------<br>
	$(nls "Show system logs on 12 console") <check id=system_logs checked=0><br>
	------------------------------------------------------------------<br>
	<menu id=edit_menu hidden=1>
	<item id=vim> vim
	<item id=jed> jed
	<item id=mcedit> mcedit
	<item id=nano> nano
	<item id=joe> joe
	<item id=pico> pico
	</menu><br>
	<check id=system_editor> $(nls "Editor"): <input id=editor menu=edit_menu width=10 label=Lista caption=$PLDCONF_EDITOR title="$(nls "Editors...")"><br>$(nls "it's default system editor")<br>
	$(nls "Updated slocate database (file finder)") 
	<button id=updatedb caption="$(nls "Update")"><BR><BR>
	\`dml_buttons Ok Anuluj Pomoc Wyjcie\`<br>
EOF`

	dml_cancel_check ${EXEC_PREFIX}/pldconf 
	dml_help_check ${DATA_DIR}/POMOC/README_inne.txt
	dml_check_the_rest ${EXEC_PREFIX}/pldconf
}

gui()
{
	eval `dml<< EOF
	<meta title="$(nls "Other")" width=72><br>
	$(nls "Set date (month, day, hour, minute, year)"): <input id=date width=12><br>
	<check id=time_sync> $(nls "Synchronize time from internet")<br>
	------------------------------------------------------------------<br>
	$(nls "Language") ($(nls "eg. en_EN")): <input id=lang width=8><br>
	------------------------------------------------------------------<br>
	$(nls "User"): <input id=users_to_sudo_group width=12> $(nls "can use root account (sudo)")<br>
	<check id=sudo_nopass> $(nls "Don't require password to use root account (sudo)")<br>
	------------------------------------------------------------------<br>
	<input id=beeper_volume width=6> $(nls "Beeper volume on console [0-2000]  (Desktop module for X)")<br>
	------------------------------------------------------------------<br>
	$(nls "ctrl+alt+del can do:")<br>
	<menu id=init> 
	<item id=leave> $(nls "leave the same options")
	<item id=restart> $(nls "restart")
	<item id=shutdown> $(nls "shutdown")
	</menu>
	------------------------------------------------------------------<br><br>
	<button id=more_opts caption="$(nls "More options")"><br>
	\`dml_buttons Ok Anuluj Pomoc Wyjcie\`<br>
EOF`

	dml_cancel_check ${EXEC_PREFIX}/pldconf 
	dml_help_check ${DATA_DIR}/POMOC/README_inne.txt
	dml_check_the_rest ${EXEC_PREFIX}/pldconf

	[ "$more_opts" = "yes" ] && gui2
}

print_help()
{
	cat << EOF
$(nls "Options:")
-d $(nls "<date>		set date MMDDhhmmYY");
-t $(nls "synchronize time from internet");
-l $(nls "<lang>		set language");
-s $(nls "<user [users]>	user can use root account; it'ss possible
to set more users using qutation marks, 
e.g.: pldconf -I -s ") "jozef mieczyslaw wladyslaw";
-p $(nls "Don't require password to use root account (sudo)")
-b $(nls "<volume>	 beeper volume on console [0-2000]");
-i <restart/shutdown>	$(nls "ctrl+alt+del mode");
-S $(nls "<partition>		set swap on partition");
-H $(nls "set shutdown motherboard after shutdown command")
-h $(nls "help")
$(nls "no options run GUI")
EOF
}

while getopts "d:tl:ps:b:i:S:P:ABCHh" opt
do
	case $opt in
		d ) date="$OPTARG";;
		t ) time_sync="yes";;
		l ) lang="$OPTARG";;
		s ) users_to_sudo_group="$OPTARG";;
		p ) sudo_nopass="yes";;
		b ) beeper_volume="$OPTARG";;
		i ) init="$OPTARG";;
		S ) swap="$OPTARG";;
		H ) halt_and_off="yes";;
		h ) print_help; exit;; 
		? ) print_help; exit;; 
	esac
done

[ -z "$1" ] && gui || run_main 2>/dev/null
