#!/bin/bash
#GPL, mimooh at pld-linux.org
#PLD installer, source can be net or mountable media with rpms

create_template() {
	cat > /etc/pldconf/pld_install_template <<- EOF  
	#$(nls "Parition on which system will be installed")
	root_part=/dev/hda5

	#$(nls "Swap partition")
	swap_part=/dev/hda2

	#$(nls "command to format root_part") (mkfs.ext3 | mkfs.reiserfs | mkfs.xfs | mkfs.ext2)
	#$(nls "use 'echo' to skip formatting")
	format_command=mkfs.ext3

	#$(nls "root_part filesystem (most likely related to format_command)")
	fs_type=ext3

	#$(nls "Network source to be used")
	#poldek_source=ftp://ftp.nest.pld-linux.org/test/i386/
	#poldek_source=ftp://ftp.pld-linux.org/dists/ac/PLD/i686/PLD/RPMS/
	#poldek_source=http://public.inf.sgsp.edu.pl/LINUZ/DISTROS/PLD/AC/i586/
	
	#$(nls "rpms on mountable device (path is ended by slash)")
	#rpms_device=/dev/hda1
	#poldek_source=/path/to/rpms/
	
	EOF
}

greeting() {
	clear
	cat <<- EOF


	$(nls "PLD Installer")
	~~~~~~~~~~~~~~

	1. $(nls "Set up partition") (fdisk)
	2. $(nls "In case you use network, configure it by pldconf -n")
	3. $(nls "Make sure files below have correct content:")
	/etc/modules && /etc/modules.conf || /etc/modprobe.conf 

	$(nls "You have to perform these actions yourself before starting the installation. Next $EDITOR /etc/pldconf/pld_install_template will be started - setup installer configuration. Real installation will be started using command: ")

	pldconf -D -f 

	$(nls "Then installer setup will be displayed. Installer will wait 8 seconds before installation starts - this time should be sufficient to check configuration once more, <ctrl+c> breaks installation")


	<enter> $(nls "starting $EDITOR /etc/pldconf/pld_install_template")
	EOF
	read
	$EDITOR /etc/pldconf/pld_install_template
	exit
}

display_settings() {
	echo "$(nls "Partition config:")"
	modprobe ide-disk
	fdisk -l /dev/hda /dev/hdb /dev/hdc /dev/hdd /dev/hde /dev/sda
	cat <<- EOF

	$(nls "PLD installation starts in 8 seconds")

	root_part=$root_part
	swap_part=$swap_part
	format_command=$format_command
	fs_type=$fs_type
	poldek_source=$poldek_source
	rpms_device=$rpms_device


	$(nls "<ctrl+c> break")
	EOF
	sleep 8
}

last_action_verify() {
	[ $? -eq 0 ] && { echo; echo $1: OK; sleep 1; } || { echo; echo $1: Problemy; exit; }
}

prepare_source() {
	cp /etc/poldek.conf /etc/poldek.pldconf.bak
	if [ "$rpms_device" ]; then
		umount $rpms_device 2>/dev/null
		mkdir -p /mnt/poldek_source /root/poldek_index
		echo source0 = /root/poldek_index/ > /etc/poldek.conf
		echo prefix0 = /mnt/poldek_source/$poldek_source >> /etc/poldek.conf

		mount $rpms_device /mnt/poldek_source
		last_action_verify "mount $rpms_device /mnt/poldek_source"
		poldek --mkidxz -s /root/poldek_index --prefix=/mnt/poldek_source/$poldek_source --nodiff
		last_action_verify "Tworzenie indeksw dla poldka"

		mkdir -p /mnt/pld-inst/mnt/poldek_source/ /mnt/pld-inst/root/poldek_index/ /mnt/pld-inst/root/tmp/
		cp -r /root/poldek_index/* /mnt/pld-inst/root/poldek_index/
	else
		echo source = $poldek_source > /etc/poldek.conf
	fi
	cp /etc/poldek.conf /mnt/pld-inst/etc/poldek.conf
}

run_main() {

	cp /etc/modules.conf /etc/modules.conf.temp
	cp /etc/modprobe.conf /etc/modprobe.conf.temp
	cp /etc/modules /etc/modules.temp
	mkdir -p /mnt/pld-inst/

	$format_command $root_part 
	last_action_verify "$(nls "Creating filesystem $format_command on $root_part")"

	mkswap $swap_part
	last_action_verify "$(nls "Creating swap on $swap_part")"

 	mount $root_part /mnt/pld-inst || mount -t $fs_type $root_part /mnt/pld-inst
	last_action_verify "mount $root_part /mnt/pld-inst"

	rm -rf /mnt/pld-inst/* 2>/dev/null
	mkdir -p /mnt/pld-inst/var/lib/rpm
	mkdir -p /mnt/pld-inst/etc/sysconfig/interfaces/
	rpm --initdb --root=/mnt/pld-inst

	cat > /mnt/pld-inst/etc/fstab << EOF
$root_part		/			$fs_type defaults	1 1
$swap_part		swap			swap	defaults	0 0

none			/proc			proc	defaults,gid=17	0 0
none			/dev/pts		devpts	gid=5,mode=620	0 0
#none			/dev/shm		shmfs	defaults	0 0
#none			/dev			devfs	defaults	0 0

/dev/fd0		/media/floppy		auto	user,noauto	0 0
/dev/cdrom              /media/cdrom      	iso9660 noauto,ro,user,unhide   0 0
EOF

	prepare_source
	
	echo "LANG=pl_PL" > /mnt/pld-inst/etc/sysconfig/i18n

	echo "$(nls "Ignore errors that may appear now")"
	sleep 2
	poldek --root=/mnt/pld-inst --nodeps --force -iv poldek bash openssl pcre mount vim terminfo
	
	cat > /mnt/pld-inst/root/pld_install_continue.sh << EOF
echo; echo "chroot /mnt/pld-inst: OK"
sleep 1
[ "$rpms_device" ] && { mount $rpms_device /mnt/poldek_source || exit; }
mount -o remount /
poldek -iv modutils 
mv /etc/modules.conf.temp /etc/modules.conf
mv /etc/modprobe.conf.temp /etc/modprobe.conf || cp /etc/modules.conf /etc/modprobe.conf
mv /etc/modules.temp /etc/modules
mount /proc
poldek -iv kernel-grsecurity grub pldconf less localedb-src kbd wget lynx mtr
localedb-gen -l pl_PL
echo root:root | chpasswd
echo "Konfiguracja menedera startu GRUB (pldconf -b -a)"
pldconf -b -a
#. /usr/share/pldconf/pldconf_functions && setup_perms 
chmod 640 /etc/{modprobe.conf,modules.conf} 2>/dev/null
chmod 644 /etc/{modules,fstab,hosts,poldek.conf,resolv.conf,inittab,profile,group} 2>/dev/null
chmod 644 /boot/grub/menu.lst 2>/dev/null
chmod 700 /etc/sysconfig/ 2>/dev/null
chmod 644 /etc/sysconfig/{i18n,interfaces/ifcfg-*,mouse,hdparm,clock,rdate,clock} 2>/dev/null
exit
EOF
	cp /etc/modules.conf.temp /mnt/pld-inst/etc/
	cp /etc/modprobe.conf /mnt/pld-inst/etc/modprobe.conf.temp 2>/dev/null
	cp /etc/modules.temp /mnt/pld-inst/etc/
	cp /etc/resolv.conf /mnt/pld-inst/etc/resolv.conf
	cp -R /root/.poldek-cache /mnt/pld-inst/root/
	chmod 755 /mnt/pld-inst/root/pld_install_continue.sh
	
	umount $rpms_device 2>/dev/null
	chroot /mnt/pld-inst /root/pld_install_continue.sh
	cp /etc/sysconfig/network /mnt/pld-inst/etc/sysconfig/network
	cp /etc/sysconfig/interfaces/ifcfg-eth* /mnt/pld-inst/etc/sysconfig/interfaces/
	cp /etc/hosts /mnt/pld-inst/etc/hosts
	mv /etc/poldek.pldconf.bak /etc/poldek.conf

	cat << EOF


	$(nls "Password for root:") root
	$(nls "Installation completed. If you want to correct something, run this command")

      		chroot /mnt/pld-inst bash
EOF
}

[ -n "$EDITOR" ] || export EDITOR=vim
[ -f "/etc/pldconf/pld_install_template" ] || create_template
[ "X$1" != "X-f" ] && greeting 	# only pldconf -D -f does real install - greeting() otherwise
				# $1 is not a bug here, /usr/bin/pldconf shifts -D
. /etc/pldconf/pld_install_template && display_settings || exit
umount /mnt/pld-inst 2>/dev/null
run_main


